@@ -14,7 +14,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Type, Union, overload
+from typing import Any, Dict, Mapping, Sequence, Type, Union, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -55,7 +55,7 @@ __all__ = ("EMRContainersClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -69,7 +69,7 @@ class Exceptions:
 
 class EMRContainersClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html)
     """
 
@@ -85,7 +85,7 @@ class EMRContainersClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#can_paginate)
         """
 
@@ -93,7 +93,7 @@ class EMRContainersClient(BaseClient):
         """
         Cancels a job run.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Client.cancel_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Client.cancel_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#cancel_job_run)
         """
 
@@ -108,12 +108,12 @@ class EMRContainersClient(BaseClient):
         certificateArn: str,
         clientToken: str,
         configurationOverrides: "ConfigurationOverridesTypeDef" = None,
-        tags: Dict[str, str] = None
+        tags: Mapping[str, str] = None
     ) -> CreateManagedEndpointResponseTypeDef:
         """
         Creates a managed endpoint.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Client.create_managed_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Client.create_managed_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#create_managed_endpoint)
         """
 
@@ -123,12 +123,12 @@ class EMRContainersClient(BaseClient):
         name: str,
         containerProvider: "ContainerProviderTypeDef",
         clientToken: str,
-        tags: Dict[str, str] = None
+        tags: Mapping[str, str] = None
     ) -> CreateVirtualClusterResponseTypeDef:
         """
         Creates a virtual cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Client.create_virtual_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Client.create_virtual_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#create_virtual_cluster)
         """
 
@@ -138,7 +138,7 @@ class EMRContainersClient(BaseClient):
         """
         Deletes a managed endpoint.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Client.delete_managed_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Client.delete_managed_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#delete_managed_endpoint)
         """
 
@@ -146,7 +146,7 @@ class EMRContainersClient(BaseClient):
         """
         Deletes a virtual cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Client.delete_virtual_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Client.delete_virtual_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#delete_virtual_cluster)
         """
 
@@ -154,7 +154,7 @@ class EMRContainersClient(BaseClient):
         """
         Displays detailed information about a job run.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Client.describe_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Client.describe_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#describe_job_run)
         """
 
@@ -164,7 +164,7 @@ class EMRContainersClient(BaseClient):
         """
         Displays detailed information about a managed endpoint.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Client.describe_managed_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Client.describe_managed_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#describe_managed_endpoint)
         """
 
@@ -172,21 +172,21 @@ class EMRContainersClient(BaseClient):
         """
         Displays detailed information about a specified virtual cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Client.describe_virtual_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Client.describe_virtual_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#describe_virtual_cluster)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#generate_presigned_url)
         """
 
@@ -197,14 +197,14 @@ class EMRContainersClient(BaseClient):
         createdBefore: Union[datetime, str] = None,
         createdAfter: Union[datetime, str] = None,
         name: str = None,
-        states: List[JobRunStateType] = None,
+        states: Sequence[JobRunStateType] = None,
         maxResults: int = None,
         nextToken: str = None
     ) -> ListJobRunsResponseTypeDef:
         """
         Lists job runs based on a set of parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Client.list_job_runs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Client.list_job_runs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#list_job_runs)
         """
 
@@ -214,15 +214,15 @@ class EMRContainersClient(BaseClient):
         virtualClusterId: str,
         createdBefore: Union[datetime, str] = None,
         createdAfter: Union[datetime, str] = None,
-        types: List[str] = None,
-        states: List[EndpointStateType] = None,
+        types: Sequence[str] = None,
+        states: Sequence[EndpointStateType] = None,
         maxResults: int = None,
         nextToken: str = None
     ) -> ListManagedEndpointsResponseTypeDef:
         """
         Lists managed endpoints based on a set of parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Client.list_managed_endpoints)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Client.list_managed_endpoints)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#list_managed_endpoints)
         """
 
@@ -230,7 +230,7 @@ class EMRContainersClient(BaseClient):
         """
         Lists the tags assigned to the resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#list_tags_for_resource)
         """
 
@@ -241,14 +241,14 @@ class EMRContainersClient(BaseClient):
         containerProviderType: Literal["EKS"] = None,
         createdAfter: Union[datetime, str] = None,
         createdBefore: Union[datetime, str] = None,
-        states: List[VirtualClusterStateType] = None,
+        states: Sequence[VirtualClusterStateType] = None,
         maxResults: int = None,
         nextToken: str = None
     ) -> ListVirtualClustersResponseTypeDef:
         """
         Lists information about the specified virtual cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Client.list_virtual_clusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Client.list_virtual_clusters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#list_virtual_clusters)
         """
 
@@ -262,35 +262,35 @@ class EMRContainersClient(BaseClient):
         jobDriver: "JobDriverTypeDef",
         name: str = None,
         configurationOverrides: "ConfigurationOverridesTypeDef" = None,
-        tags: Dict[str, str] = None
+        tags: Mapping[str, str] = None
     ) -> StartJobRunResponseTypeDef:
         """
         Starts a job run.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Client.start_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Client.start_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#start_job_run)
         """
 
-    def tag_resource(self, *, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
+    def tag_resource(self, *, resourceArn: str, tags: Mapping[str, str]) -> Dict[str, Any]:
         """
         Assigns tags to resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, resourceArn: str, tagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Removes tags from resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/client.html#untag_resource)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_job_runs"]) -> ListJobRunsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listjobrunspaginator)
         """
 
@@ -299,7 +299,7 @@ class EMRContainersClient(BaseClient):
         self, operation_name: Literal["list_managed_endpoints"]
     ) -> ListManagedEndpointsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listmanagedendpointspaginator)
         """
 
@@ -308,6 +308,6 @@ class EMRContainersClient(BaseClient):
         self, operation_name: Literal["list_virtual_clusters"]
     ) -> ListVirtualClustersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listvirtualclusterspaginator)
         """
