@@ -24,7 +24,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Generic, Iterator, List, TypeVar, Union
+from typing import Generic, Iterator, Sequence, TypeVar, Union
 
 from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
@@ -58,7 +58,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListJobRunsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listjobrunspaginator)
     """
 
@@ -69,18 +69,18 @@ class ListJobRunsPaginator(Boto3Paginator):
         createdBefore: Union[datetime, str] = None,
         createdAfter: Union[datetime, str] = None,
         name: str = None,
-        states: List[JobRunStateType] = None,
+        states: Sequence[JobRunStateType] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListJobRunsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listjobrunspaginator)
         """
 
 
 class ListManagedEndpointsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listmanagedendpointspaginator)
     """
 
@@ -90,19 +90,19 @@ class ListManagedEndpointsPaginator(Boto3Paginator):
         virtualClusterId: str,
         createdBefore: Union[datetime, str] = None,
         createdAfter: Union[datetime, str] = None,
-        types: List[str] = None,
-        states: List[EndpointStateType] = None,
+        types: Sequence[str] = None,
+        states: Sequence[EndpointStateType] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListManagedEndpointsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listmanagedendpointspaginator)
         """
 
 
 class ListVirtualClustersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listvirtualclusterspaginator)
     """
 
@@ -113,10 +113,10 @@ class ListVirtualClustersPaginator(Boto3Paginator):
         containerProviderType: Literal["EKS"] = None,
         createdAfter: Union[datetime, str] = None,
         createdBefore: Union[datetime, str] = None,
-        states: List[VirtualClusterStateType] = None,
+        states: Sequence[VirtualClusterStateType] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListVirtualClustersResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/paginators.html#listvirtualclusterspaginator)
         """
